/*
 * Obtain object statistics from a filesystem.
 *
 * Copyright (C) 2019, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdio.h>

#include <sys/stat.h>
#include <sys/sysmacros.h>  /* major, minor */
#include <sys/types.h>

#include <fsclient/client.h>

#include "ops.h"



/* Show statistics for files and directories. */

int stat_objects(int argc, char *argv[])
{
    int i;
    const char *path;
    struct stat st;

    for (i = 0; i < argc; i++)
    {
        path = argv[i];

        /* Detect missing objects. */

        if (client_stat(path, &st))
        {
            fprintf(stderr, "Cannot stat object: %s\n", path);
            return 1;
        }

        /* Terse stat output:
           %n %s %b %f %u %g %D %i %h %t %T %X %Y %Z %W %o %C */

        printf("%s %ld %ld %x %d %d ",
            path, st.st_size, st.st_blocks, st.st_mode, st.st_uid, st.st_gid);

        printf("%ld %ld %ld %x %x ",
            st.st_dev, st.st_ino, st.st_nlink,
            major(st.st_rdev), minor(st.st_rdev));

        printf("%ld %ld %ld ",
            st.st_atim.tv_sec, st.st_mtim.tv_sec, st.st_ctim.tv_sec);

        /* NOTE: Arbitrary values:
           %W (creation time) given as 0
           %o (I/O transfer size hint) given as 0
           %C (SELinux security context) given as empty string */

        printf("%d %d %s\n",
            0, 0, "");
    }

    return 0;
}

/* vim: tabstop=4 expandtab shiftwidth=4
*/
